#include "petsclib.h"

#if (PETSC_VERSION_MAJOR    == 2 && \
     PETSC_VERSION_MINOR    == 3 && \
     PETSC_VERSION_SUBMINOR == 2 && \
     PETSC_VERSION_RELEASE  == 1)
#define PETSCMAT_DLL
#include "src/mat/impls/is/matis.c"
#undef  PETSCMAT_DLL
#endif

#define PETSCKSP_DLL
#include "src/ksp/pc/impls/schur/schur.c"
#undef PETSCKSP_DLL

#define PETSCTS_DLL
#include "src/ts/impls/implicit/user/user.c"
#undef PETSCTS_DLL
